@@ -25,12 +25,6 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-// Dependencies
-#[cfg(os_target = "windows")]
-extern crate path_slash;
-extern crate regex;
-extern crate ssh2;
-
 // Locals
 use super::{FileTransfer, FileTransferError, FileTransferErrorType};
 use crate::fs::{FsDirectory, FsEntry, FsFile};
