@@ -28,8 +28,6 @@
 // Mods
 pub(crate) mod builder;
 mod formatter;
-// Deps
-extern crate bitflags;
 // Locals
 use super::FsEntry;
 use formatter::Formatter;
