@@ -25,25 +25,23 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-// deps
-extern crate bytesize;
 // locals
 use super::{
     actions::SelectedEntry, browser::FileExplorerTab, FileTransferActivity, LogLevel,
     COMPONENT_EXPLORER_FIND, COMPONENT_EXPLORER_LOCAL, COMPONENT_EXPLORER_REMOTE,
     COMPONENT_INPUT_COPY, COMPONENT_INPUT_EXEC, COMPONENT_INPUT_FIND, COMPONENT_INPUT_GOTO,
-    COMPONENT_INPUT_MKDIR, COMPONENT_INPUT_NEWFILE, COMPONENT_INPUT_RENAME, COMPONENT_INPUT_SAVEAS,
-    COMPONENT_LIST_FILEINFO, COMPONENT_LOG_BOX, COMPONENT_PROGRESS_BAR_FULL,
-    COMPONENT_PROGRESS_BAR_PARTIAL, COMPONENT_RADIO_DELETE, COMPONENT_RADIO_DISCONNECT,
-    COMPONENT_RADIO_QUIT, COMPONENT_RADIO_SORTING, COMPONENT_TEXT_ERROR, COMPONENT_TEXT_FATAL,
-    COMPONENT_TEXT_HELP,
+    COMPONENT_INPUT_MKDIR, COMPONENT_INPUT_NEWFILE, COMPONENT_INPUT_OPEN_WITH,
+    COMPONENT_INPUT_RENAME, COMPONENT_INPUT_SAVEAS, COMPONENT_LIST_FILEINFO, COMPONENT_LOG_BOX,
+    COMPONENT_PROGRESS_BAR_FULL, COMPONENT_PROGRESS_BAR_PARTIAL, COMPONENT_RADIO_DELETE,
+    COMPONENT_RADIO_DISCONNECT, COMPONENT_RADIO_QUIT, COMPONENT_RADIO_SORTING,
+    COMPONENT_TEXT_ERROR, COMPONENT_TEXT_FATAL, COMPONENT_TEXT_HELP,
 };
 use crate::fs::explorer::FileSorting;
 use crate::fs::FsEntry;
 use crate::ui::components::{file_list::FileListPropsBuilder, logbox::LogboxPropsBuilder};
 use crate::ui::keymap::*;
+use crate::utils::fmt::fmt_path_elide_ex;
 // externals
-use std::path::{Path, PathBuf};
 use tuirealm::{
     components::progress_bar::ProgressBarPropsBuilder,
     props::{PropsBuilder, TableBuilder, TextSpan, TextSpanBuilder},
@@ -87,7 +85,7 @@ impl Update for FileTransferActivity {
                         entry = Some(e.clone());
                     }
                     if let Some(entry) = entry {
-                        if self.action_enter_local_dir(entry, false) {
+                        if self.action_submit_local(entry) {
                             // Update file list if sync
                             if self.browser.sync_browsing {
                                 let _ = self.update_remote_filelist();
@@ -120,8 +118,7 @@ impl Update for FileTransferActivity {
                 }
                 (COMPONENT_EXPLORER_LOCAL, &MSG_KEY_CHAR_L) => {
                     // Reload directory
-                    let pwd: PathBuf = self.local().wrkdir.clone();
-                    self.local_scan(pwd.as_path());
+                    self.reload_local_dir();
                     // Reload file list component
                     self.update_local_filelist()
                 }
@@ -152,7 +149,7 @@ impl Update for FileTransferActivity {
                         entry = Some(e.clone());
                     }
                     if let Some(entry) = entry {
-                        if self.action_enter_remote_dir(entry, false) {
+                        if self.action_submit_remote(entry) {
                             // Update file list if sync
                             if self.browser.sync_browsing {
                                 let _ = self.update_local_filelist();
@@ -195,8 +192,7 @@ impl Update for FileTransferActivity {
                 }
                 (COMPONENT_EXPLORER_REMOTE, &MSG_KEY_CHAR_L) => {
                     // Reload directory
-                    let pwd: PathBuf = self.remote().wrkdir.clone();
-                    self.remote_scan(pwd.as_path());
+                    self.reload_remote_dir();
                     // Reload file list component
                     self.update_remote_filelist()
                 }
@@ -270,6 +266,26 @@ impl Update for FileTransferActivity {
                     self.mount_saveas();
                     None
                 }
+                (COMPONENT_EXPLORER_LOCAL, &MSG_KEY_CHAR_V)
+                | (COMPONENT_EXPLORER_REMOTE, &MSG_KEY_CHAR_V)
+                | (COMPONENT_EXPLORER_FIND, &MSG_KEY_CHAR_V) => {
+                    // View
+                    match self.browser.tab() {
+                        FileExplorerTab::Local => self.action_open_local(),
+                        FileExplorerTab::Remote => self.action_open_remote(),
+                        FileExplorerTab::FindLocal | FileExplorerTab::FindRemote => {
+                            self.action_find_open()
+                        }
+                    }
+                    None
+                }
+                (COMPONENT_EXPLORER_LOCAL, &MSG_KEY_CHAR_W)
+                | (COMPONENT_EXPLORER_REMOTE, &MSG_KEY_CHAR_W)
+                | (COMPONENT_EXPLORER_FIND, &MSG_KEY_CHAR_W) => {
+                    // Open with
+                    self.mount_openwith();
+                    None
+                }
                 (COMPONENT_EXPLORER_LOCAL, &MSG_KEY_CHAR_X)
                 | (COMPONENT_EXPLORER_REMOTE, &MSG_KEY_CHAR_X) => {
                     // Mount exec
@@ -350,12 +366,14 @@ impl Update for FileTransferActivity {
                 }
                 (COMPONENT_INPUT_COPY, Msg::OnSubmit(Payload::One(Value::Str(input)))) => {
                     // Copy file
+                    self.umount_copy();
+                    self.mount_blocking_wait("Copying file(s)…");
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.action_local_copy(input.to_string()),
                         FileExplorerTab::Remote => self.action_remote_copy(input.to_string()),
                         _ => panic!("Found tab doesn't support COPY"),
                     }
-                    self.umount_copy();
+                    self.umount_wait();
                     // Reload files
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.update_local_filelist(),
@@ -363,6 +381,7 @@ impl Update for FileTransferActivity {
                         _ => None,
                     }
                 }
+                (COMPONENT_INPUT_COPY, _) => None,
                 // -- exec popup
                 (COMPONENT_INPUT_EXEC, &MSG_KEY_ESC) => {
                     self.umount_exec();
@@ -370,12 +389,14 @@ impl Update for FileTransferActivity {
                 }
                 (COMPONENT_INPUT_EXEC, Msg::OnSubmit(Payload::One(Value::Str(input)))) => {
                     // Exex command
+                    self.umount_exec();
+                    self.mount_blocking_wait(format!("Executing '{}'…", input).as_str());
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.action_local_exec(input.to_string()),
                         FileExplorerTab::Remote => self.action_remote_exec(input.to_string()),
                         _ => panic!("Found tab doesn't support EXEC"),
                     }
-                    self.umount_exec();
+                    self.umount_wait();
                     // Reload files
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.update_local_filelist(),
@@ -383,6 +404,7 @@ impl Update for FileTransferActivity {
                         _ => None,
                     }
                 }
+                (COMPONENT_INPUT_EXEC, _) => None,
                 // -- find popup
                 (COMPONENT_INPUT_FIND, &MSG_KEY_ESC) => {
                     self.umount_find_input();
@@ -450,6 +472,7 @@ impl Update for FileTransferActivity {
                         _ => None,
                     }
                 }
+                (COMPONENT_INPUT_GOTO, _) => None,
                 // -- make directory
                 (COMPONENT_INPUT_MKDIR, &MSG_KEY_ESC) => {
                     self.umount_mkdir();
@@ -469,6 +492,7 @@ impl Update for FileTransferActivity {
                         _ => None,
                     }
                 }
+                (COMPONENT_INPUT_MKDIR, _) => None,
                 // -- new file
                 (COMPONENT_INPUT_NEWFILE, &MSG_KEY_ESC) => {
                     self.umount_newfile();
@@ -488,18 +512,38 @@ impl Update for FileTransferActivity {
                         _ => None,
                     }
                 }
+                (COMPONENT_INPUT_NEWFILE, _) => None,
+                // -- open with
+                (COMPONENT_INPUT_OPEN_WITH, &MSG_KEY_ESC) => {
+                    self.umount_openwith();
+                    None
+                }
+                (COMPONENT_INPUT_OPEN_WITH, Msg::OnSubmit(Payload::One(Value::Str(input)))) => {
+                    match self.browser.tab() {
+                        FileExplorerTab::Local => self.action_local_open_with(input),
+                        FileExplorerTab::Remote => self.action_remote_open_with(input),
+                        FileExplorerTab::FindLocal | FileExplorerTab::FindRemote => {
+                            self.action_find_open_with(input)
+                        }
+                    }
+                    self.umount_openwith();
+                    None
+                }
+                (COMPONENT_INPUT_OPEN_WITH, _) => None,
                 // -- rename
                 (COMPONENT_INPUT_RENAME, &MSG_KEY_ESC) => {
                     self.umount_rename();
                     None
                 }
                 (COMPONENT_INPUT_RENAME, Msg::OnSubmit(Payload::One(Value::Str(input)))) => {
+                    self.umount_rename();
+                    self.mount_blocking_wait("Moving file(s)…");
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.action_local_rename(input.to_string()),
                         FileExplorerTab::Remote => self.action_remote_rename(input.to_string()),
                         _ => panic!("Found tab doesn't support RENAME"),
                     }
-                    self.umount_rename();
+                    self.umount_wait();
                     // Reload files
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.update_local_filelist(),
@@ -507,6 +551,7 @@ impl Update for FileTransferActivity {
                         _ => None,
                     }
                 }
+                (COMPONENT_INPUT_RENAME, _) => None,
                 // -- save as
                 (COMPONENT_INPUT_SAVEAS, &MSG_KEY_ESC) => {
                     self.umount_saveas();
@@ -531,12 +576,14 @@ impl Update for FileTransferActivity {
                         FileExplorerTab::FindRemote => self.update_local_filelist(),
                     }
                 }
+                (COMPONENT_INPUT_SAVEAS, _) => None,
                 // -- fileinfo
                 (COMPONENT_LIST_FILEINFO, &MSG_KEY_ENTER)
                 | (COMPONENT_LIST_FILEINFO, &MSG_KEY_ESC) => {
                     self.umount_file_info();
                     None
                 }
+                (COMPONENT_LIST_FILEINFO, _) => None,
                 // -- delete
                 (COMPONENT_RADIO_DELETE, &MSG_KEY_ESC)
                 | (COMPONENT_RADIO_DELETE, Msg::OnSubmit(Payload::One(Value::Usize(1)))) => {
@@ -545,6 +592,8 @@ impl Update for FileTransferActivity {
                 }
                 (COMPONENT_RADIO_DELETE, Msg::OnSubmit(Payload::One(Value::Usize(0)))) => {
                     // Choice is 'YES'
+                    self.umount_radio_delete();
+                    self.mount_blocking_wait("Removing file(s)…");
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.action_local_delete(),
                         FileExplorerTab::Remote => self.action_remote_delete(),
@@ -571,7 +620,7 @@ impl Update for FileTransferActivity {
                             self.update_find_list();
                         }
                     }
-                    self.umount_radio_delete();
+                    self.umount_wait();
                     // Reload files
                     match self.browser.tab() {
                         FileExplorerTab::Local => self.update_local_filelist(),
@@ -580,6 +629,7 @@ impl Update for FileTransferActivity {
                         FileExplorerTab::FindRemote => self.update_remote_filelist(),
                     }
                 }
+                (COMPONENT_RADIO_DELETE, _) => None,
                 // -- disconnect
                 (COMPONENT_RADIO_DISCONNECT, &MSG_KEY_ESC)
                 | (COMPONENT_RADIO_DISCONNECT, Msg::OnSubmit(Payload::One(Value::Usize(1)))) => {
@@ -591,6 +641,7 @@ impl Update for FileTransferActivity {
                     self.umount_disconnect();
                     None
                 }
+                (COMPONENT_RADIO_DISCONNECT, _) => None,
                 // -- quit
                 (COMPONENT_RADIO_QUIT, &MSG_KEY_ESC)
                 | (COMPONENT_RADIO_QUIT, Msg::OnSubmit(Payload::One(Value::Usize(1)))) => {
@@ -602,6 +653,7 @@ impl Update for FileTransferActivity {
                     self.umount_quit();
                     None
                 }
+                (COMPONENT_RADIO_QUIT, _) => None,
                 // -- sorting
                 (COMPONENT_RADIO_SORTING, &MSG_KEY_ESC)
                 | (COMPONENT_RADIO_SORTING, Msg::OnSubmit(_)) => {
@@ -634,27 +686,32 @@ impl Update for FileTransferActivity {
                         _ => None,
                     }
                 }
+                (COMPONENT_RADIO_SORTING, _) => None,
                 // -- error
                 (COMPONENT_TEXT_ERROR, &MSG_KEY_ESC) | (COMPONENT_TEXT_ERROR, &MSG_KEY_ENTER) => {
                     self.umount_error();
                     None
                 }
+                (COMPONENT_TEXT_ERROR, _) => None,
                 // -- fatal
                 (COMPONENT_TEXT_FATAL, &MSG_KEY_ESC) | (COMPONENT_TEXT_FATAL, &MSG_KEY_ENTER) => {
                     self.exit_reason = Some(super::ExitReason::Disconnect);
                     None
                 }
+                (COMPONENT_TEXT_FATAL, _) => None,
                 // -- help
                 (COMPONENT_TEXT_HELP, &MSG_KEY_ESC) | (COMPONENT_TEXT_HELP, &MSG_KEY_ENTER) => {
                     self.umount_help();
                     None
                 }
+                (COMPONENT_TEXT_HELP, _) => None,
                 // -- progress bar
                 (COMPONENT_PROGRESS_BAR_PARTIAL, &MSG_KEY_CTRL_C) => {
                     // Set transfer aborted to True
                     self.transfer.abort();
                     None
                 }
+                (COMPONENT_PROGRESS_BAR_PARTIAL, _) => None,
                 // -- fallback
                 (_, _) => None, // Nothing to do
             },
@@ -671,10 +728,8 @@ impl FileTransferActivity {
             Some(props) => {
                 // Get width
                 let width: usize = self
-                    .context
-                    .as_ref()
-                    .unwrap()
-                    .store
+                    .context()
+                    .store()
                     .get_unsigned(super::STORAGE_EXPLORER_WIDTH)
                     .unwrap_or(256);
                 let hostname: String = match hostname::get() {
@@ -688,12 +743,7 @@ impl FileTransferActivity {
                 let hostname: String = format!(
                     "{}:{} ",
                     hostname,
-                    FileTransferActivity::elide_wrkdir_path(
-                        self.local().wrkdir.as_path(),
-                        hostname.as_str(),
-                        width
-                    )
-                    .display()
+                    fmt_path_elide_ex(self.local().wrkdir.as_path(), width, hostname.len() + 3) // 3 because of '/…/'
                 );
                 let files: Vec<String> = self
                     .local()
@@ -719,22 +769,19 @@ impl FileTransferActivity {
             Some(props) => {
                 // Get width
                 let width: usize = self
-                    .context
-                    .as_ref()
-                    .unwrap()
-                    .store
+                    .context()
+                    .store()
                     .get_unsigned(super::STORAGE_EXPLORER_WIDTH)
                     .unwrap_or(256);
-                let params = self.context.as_ref().unwrap().ft_params.as_ref().unwrap();
+                let params = self.context().ft_params().unwrap();
                 let hostname: String = format!(
                     "{}:{} ",
                     params.address,
-                    FileTransferActivity::elide_wrkdir_path(
+                    fmt_path_elide_ex(
                         self.remote().wrkdir.as_path(),
-                        params.address.as_str(),
-                        width
+                        width,
+                        params.address.len() + 3 // 3 because of '/…/'
                     )
-                    .display()
                 );
                 let files: Vec<String> = self
                     .remote()
@@ -857,38 +904,4 @@ impl FileTransferActivity {
             }
         }
     }
-
-    /// ### elide_wrkdir_path
-    ///
-    /// Elide working directory path if longer than width + host.len
-    /// In this case, the path is formatted to {ANCESTOR[0]}/.../{PARENT[0]}/{BASENAME}
-    fn elide_wrkdir_path(wrkdir: &Path, host: &str, width: usize) -> PathBuf {
-        let fmt_path: String = format!("{}", wrkdir.display());
-        // NOTE: +5 is const
-        match fmt_path.len() + host.len() + 5 > width {
-            false => PathBuf::from(wrkdir),
-            true => {
-                // Elide
-                let ancestors_len: usize = wrkdir.ancestors().count();
-                let mut ancestors = wrkdir.ancestors();
-                let mut elided_path: PathBuf = PathBuf::new();
-                // If ancestors_len's size is bigger than 2, push count - 2
-                if ancestors_len > 2 {
-                    elided_path.push(ancestors.nth(ancestors_len - 2).unwrap());
-                }
-                // If ancestors_len is bigger than 3, push '...' and parent too
-                if ancestors_len > 3 {
-                    elided_path.push("...");
-                    if let Some(parent) = wrkdir.ancestors().nth(1) {
-                        elided_path.push(parent.file_name().unwrap());
-                    }
-                }
-                // Push file_name
-                if let Some(name) = wrkdir.file_name() {
-                    elided_path.push(name);
-                }
-                elided_path
-            }
-        }
-    }
 }
